VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "LocaleSettings"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
Option Explicit
' CGLocale Class
' This DLL allows you to obtain the Regional Settings for your System.
' This will ensure that all displays etc are correct for the country of use
'

Public Property Get DateFormat() As String
    ' This function will return the Locale date format for the system. Note that the
    ' returned Year is always formatted to 'YYYY' regardless, to ensure Y2k compliance.
    Dim sDateFormat As String
    On Error GoTo vbErrorHandler
    sDateFormat = GetLocaleString(LOCALE_SSHORTDATE)

    ' Make sure we always have YYYY format for y2k
    If InStr(1, sDateFormat, "YYYY", vbTextCompare) = 0 Then
        Replace sDateFormat, "YY", "YYYY"
    End If
    DateFormat = sDateFormat
Exit Property
vbErrorHandler:
    Err.Raise Err.Number, "CGLocaleInfo GetDateFormat", Err.Description
End Property

Public Property Get TimeFormat() As String
    'This function returns the locale's defined Time Format.
    TimeFormat = GetLocaleString(LOCALE_STIMEFORMAT)
Exit Property
vbErrorHandler:
    Err.Raise Err.Number, "CGLocaleInfo GetTimeFormat", Err.Description
End Property

Public Property Get NumberFormat() As String
' This function returns the Locales defined Decimal Number format
    Dim lBuffLen As Long
    Dim sBuffer As String
    Dim sDecimal As String
    Dim sThousand As String
    Dim lResult As Long
    Dim sNumFormat As String

    On Error GoTo vbErrorHandler

    'Setup a buffer to receive the settings
    lBuffLen = 128
    sBuffer = String$(lBuffLen, vbNullChar)

    lResult = GetLocaleInfo(LOCALE_USER_DEFAULT, LOCALE_SDECIMAL, sBuffer, lBuffLen)
    If lResult <= 0 Then Exit Property

    sDecimal = Left$(sBuffer, lResult - 1)

    sBuffer = String$(lBuffLen, vbNullChar)
    lResult = GetLocaleInfo(LOCALE_USER_DEFAULT, LOCALE_STHOUSAND, sBuffer, lBuffLen)
    If lResult <= 0 Then Exit Property

    sThousand = Left$(sBuffer, lResult - 1)

    NumberFormat = "###" & sThousand & "###" & sDecimal & "######"
Exit Property
    
vbErrorHandler:
    Err.Raise Err.Number, "CGLocaleInfo GetNumberFormat", Err.Description
End Property

Public Property Get ThousandSpecifier() As String
    'This function returns the correct Thousand Specifier for the system Locale
    ThousandSpecifier = GetLocaleString(LOCALE_STHOUSAND)
End Property

Public Property Get DecimalSpecifier() As String
    'This function returns the correct Decimal Specifier for the system Locale
    DecimalSpecifier = GetLocaleString(LOCALE_SDECIMAL)
    
End Property

Public Property Get CurrencySpecifier() As String
    'This function returns the correct Currency Specifier for the system Locale
    CurrencySpecifier = GetLocaleString(LOCALE_SCURRENCY)
End Property

Public Property Get SysLanguageID() As Long
    'Returns the System Language ID for the machine
    SysLanguageID = GetSystemDefaultLangID
End Property

Public Property Get SysLanguageName() As String
    'Returns the System Language Name eg : English (United Kingdom)
    Dim lLangID As Long
    Dim sBuffer As String
    Dim lBuffSize As Long
    Dim lRet As Long

    On Error GoTo vbErrorHandler

    lLangID = GetSystemDefaultLangID
    'Setup a buffer to receive the settings
    lBuffSize = 50
    sBuffer = String$(lBuffSize, vbNullChar)
    lRet = VerLanguageName(lLangID, sBuffer, lBuffSize)
    If lRet > 0 Then
        SysLanguageName = Left$(sBuffer, lRet)
    End If
Exit Property
vbErrorHandler:
    Err.Raise Err.Number, "CGLocaleInfo GetSysLanguageName", Err.Description
End Property

Public Property Get ShortMonthName(ByVal iMonthNum As Integer) As String
    'Returns the short-month-name for the specified Month Number
    'eg 1=Jan, 2=Feb (on English machines)
    ShortMonthName = GetLocaleString(LOCALE_SABBREVMONTHNAME1 - 1 + iMonthNum)
End Property

Public Property Get MonthName(ByVal iMonthNum As Integer) As String
    'Returns the Full-Month-Name for the specified month number
    'eg. 1=January, 2=February (on english machines)
    MonthName = GetLocaleString(LOCALE_SMONTHNAME1 + iMonthNum - 1)
End Property

Public Property Get ShortDayName(ByVal iDayNum As Integer) As String
    'Returns the Short-Day-Name for the specified Day Number
    'eg. 1=Mon, 2=Tue (on english machines)
    ShortDayName = GetLocaleString(LOCALE_SABBREVDAYNAME1 + iDayNum - 1)
End Property

Public Property Get DayName(ByVal iDayNum As Integer) As String
    'Returns the Full Day Name for the specified Day number
    'eg. 1=Monday, 2=Tuesday (on english machines)
    DayName = GetLocaleString(LOCALE_SDAYNAME1 + iDayNum - 1)
End Property

Public Property Get Country() As String
    'Returns the Country Name eg. 'United Kingdom'
    Country = GetLocaleString(LOCALE_SENGCOUNTRY)
End Property

Public Property Get LanguageName() As String
    'Returns the Native Language Name eg. 'English'
    LanguageName = GetLocaleString(LOCALE_SNATIVELANGNAME)
End Property

Public Property Get NativeCountryName() As String
    NativeCountryName = GetLocaleString(LOCALE_SNATIVECTRYNAME)
End Property

Public Property Get PositiveSign() As String
    'Returns the symbol used for the positive sign eg. +
    PositiveSign = GetLocaleString(LOCALE_SPOSITIVESIGN)
End Property

Public Property Get NegativeSign() As String
' Returns the symbol used for the negative sign eg. -
    NegativeSign = GetLocaleString(LOCALE_SNEGATIVESIGN)
End Property

Private Function GetLocaleString(ByVal lLocaleNum As Long) As String
    'Generic routine to get the locale string from the Operating system.
    Dim lBuffSize As String
    Dim sBuffer As String
    Dim lRet As Long

    lBuffSize = 256
    sBuffer = String$(lBuffSize, vbNullChar)

    'Get the information from the registry
    lRet = GetLocaleInfo(LOCALE_USER_DEFAULT, lLocaleNum, sBuffer, lBuffSize)
    'If lRet > 0 then success - lret is the size of the string returned
    If lRet > 0 Then
        GetLocaleString = Left$(sBuffer, lRet - 1)
    End If
End Function

Private Sub Replace(ByRef sOriginal As String, ByVal sLookfor As String, ByVal sReplaceBy As String)
    'Private internal routine for replacing strings
    Dim lStart As Long
    Dim lReplaceBy As Long

    On Error GoTo vbErrorHandler

    lReplaceBy = Len(sReplaceBy)
    lStart = 1
    Do
        lStart = InStr(lStart, sOriginal, sLookfor, vbTextCompare)
        If lStart > 0 Then
            sOriginal = Left$(sOriginal, lStart - 1) & sReplaceBy & Mid$(sOriginal, lStart + Len(sLookfor))
            lStart = lStart + lReplaceBy
        Else
            Exit Do
        End If
    Loop
Exit Sub
vbErrorHandler:
    Err.Raise Err.Number, "CGLocaleInfo Replace", Err.Description
End Sub
